@@ -1,15 +1,15 @@
-from feynmodel.base_class import BaseClass
+from feynmodel.ufo_base_class import UFOBaseClass
 
 
-class Decay(BaseClass):
+class Decay(UFOBaseClass):
     require_args = ["particle", "partial_widths"]
 
     def __init__(self, particle, partial_widths, **opt):
         args = (particle, partial_widths)
-        BaseClass.__init__(self, *args, **opt)
+        UFOBaseClass.__init__(self, *args, **opt)
 
-        #global all_decays
-        #all_decays.append(self)
+        # global all_decays
+        # all_decays.append(self)
 
         # Add the information directly to the particle
         particle.partial_widths = partial_widths
