@@ -1,17 +1,16 @@
 class Function(object):
+    def __init__(self, name, arguments, expr):
 
-    def __init__(self, name, arguments, expression):
-
-        #global all_functions
-        #all_functions.append(self)
+        # global all_functions
+        # all_functions.append(self)
 
         self.name = name
         self.arguments = arguments
-        self.expr = expression
-    
+        self.expr = expr
+
     def __call__(self, *opt):
 
         for i, arg in enumerate(self.arguments):
-            exec('%s = %s' % (arg, opt[i] ))
+            exec("%s = %s" % (arg, opt[i]))
 
-        return eval(self.expr)
\ No newline at end of file
+        return eval(self.expr)
